@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10247 2017-09-03 17:57:32Z David $
+# $Id: views.py 10285 2017-09-11 01:55:49Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-09-04 01:57:32 +0800 (Mon, 04 Sep 2017) $
-# $Revision: 10247 $
+# $Date: 2017-09-11 09:55:49 +0800 (Mon, 11 Sep 2017) $
+# $Revision: 10285 $
 
 import re
 import time
@@ -316,6 +316,8 @@ def recordStatus(messageId, destination, status):
         obj = cloudSrv.getCloudMailInformation(
             messageId=messageId, errorOnNotFound=False)
 
+        # Wait for cloudmailinformation set ready.
+        # See https://code.nuwainfo.com/trac/mercurius/ticket/2904#comment:14
         bufferTime = 0
 
         while not obj and bufferTime <= 15:
@@ -335,10 +337,10 @@ def recordStatus(messageId, destination, status):
                     status=status)
             amazonLogger.info("SUCCESS: Record success.")
         else:
-            amazonLogger.info("PASS: Not matched, record pass.")
+            amazonLogger.error("PASS: Not matched, record pass.")
 
     except Exception as e:
-        amazonLogger.info("FAILED: Record failed, reason: %s" % str(e))
+        amazonLogger.error("FAILED: Record failed, reason: %s" % str(e))
     finally:
         amazonLogger.info("END: Record end.")
 
@@ -351,6 +353,32 @@ def recordRejectedStatus(messageId, destination):
 def recordComplaintStatus(messageId, destination):
     recordStatus(messageId, destination, ContactMailingStatus.COMPLAINT)
 
+def isBounceType(bounceType, bounceSubType):
+    if bounceType == 'Undetermined' and bounceSubType == 'Undetermined':
+        # Bounce.
+        return True
+    elif bounceType == 'Permanent' and bounceSubType == 'General':
+        # Bounce.
+        return True
+    elif bounceType == 'Permanent' and bounceSubType == 'NoEmail':
+        # Bounce.
+        return True
+    elif bounceType == 'Transient' and bounceSubType == 'General':
+        # Bounce.
+        return True
+    elif bounceType == 'Transient' and bounceSubType == 'MailboxFull':
+        # Rejected.
+        return False
+    elif bounceType == 'Transient' and bounceSubType == 'MessageToolarge':
+        # Rejected.
+        return False
+    elif bounceType == 'Transient' and bounceSubType == 'ContentRejected':
+        # Rejected.
+        return False
+    elif bounceType == 'Transient' and bounceSubType == 'AttachmentRejected':
+        # Rejected.
+        return False
+
 import sys
 import traceback
 from urllib import urlopen
@@ -413,24 +441,31 @@ def handleSNS(request):
 
             amazonLogger.info("Message type: %s" % notificationType)
 
+            bounceDict = message.get('bounce', '')
             mail = message.get('mail', {})
             destination = mail.get('destination', [])
             messageId = mail.get('messageId', '')
+            
 
             if notificationType == 'Bounce': # Bounced.
-                # record!
-                amazonLogger.info("Got bounce, need record...")
-                recordBouncedStatus(messageId, destination)
+                # Get bounce's type.
+                bounceType = bounceDict.get('bounceType', '')
+                bounceSubType = bounceDict.get('bounceSubType', '')
+                isBounce = isBounceType(bounceType, bounceSubType)
+                if isBounce:
+                    # record!
+                    amazonLogger.info("Got bounce, need record...")
+                    recordBouncedStatus(messageId, destination)
+                else:
+                    # record!
+                    amazonLogger.info("Got rejected, need record...")
+                    recordRejectedStatus(messageId, destination)
 
             elif notificationType == 'Complaint': # Complaints.
                 # Record.
                 amazonLogger.info("Got complaint, need record...")
                 recordComplaintStatus(messageId, destination)
 
-            elif notificationType == 'Reject': # Rejects.
-                amazonLogger.info("Got reject, need record...")
-                recordRejectedStatus(messageId, destination)
-
             elif notificationType == 'Delivery': # Deliveries.
                 amazonLogger.info("Got delivery, check if need record...")
                 delivery = message.get('delivery', '')
@@ -573,22 +608,27 @@ def doSetNotificationTopic(email, useCache=False):
                     deliveryTopic, DELIVERIES_TOPIC_NAME)
 
         # Subscribe to a Topic.
+        if settings.SECURE_PROXY_SSL_HEADER:
+            protocol = settings.SECURE_PROXY_SSL_HEADER[1]
+        else:
+            protocol = 'http'
+
         bounceEndpoint = reverse(getBounces)
         if not hasBounceTopicExist:
             sns.subscribe(
-                bounceTopic, 'http',
+                bounceTopic, protocol,
                 urljoin(settings.LOCAL_URL, bounceEndpoint))
 
         complaintEndpoint = reverse(getComplains)
         if not hasComplaintTopicExist:
             sns.subscribe(
-                complaintTopic, 'http',
+                complaintTopic, protocol,
                 urljoin(settings.LOCAL_URL, complaintEndpoint))
 
         deliveryEndpoint = reverse(getDeliveries)
         if not hasDeliveryTopicExist:
             sns.subscribe(
-                deliveryTopic, 'http',
+                deliveryTopic, protocol,
                 urljoin(settings.LOCAL_URL, deliveryEndpoint))
 
         # Set notification topic.
