@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10214 2017-08-25 16:28:03Z David $
+# $Id: StatisticsHandler.py 10287 2017-09-11 02:58:59Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-08-26 00:28:03 +0800 (Sat, 26 Aug 2017) $
-# $Revision: 10214 $
+# $Date: 2017-09-11 10:58:59 +0800 (Mon, 11 Sep 2017) $
+# $Revision: 10287 $
 
 from datetime import timedelta, datetime
 
@@ -586,16 +586,13 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
             rates = []
             
             for i in info:
-                totalValue = subscriberCount
-                # if i in ('unsubscribe', 'deliverie', 'error'):
-                #     totalValue = subscriberCount
-                # elif i == 'sentTest':
-                #     totalValue = testSubscriberCount
-                # else:
-                #     totalValue = subscriberCount
-                #     totalValue = info['deliverie']        
+                if i in ('unsubscribe', 'deliverie', 'error'):
+                    totalValue = subscriberCount
+                elif i == 'sentTest':
+                    totalValue = testSubscriberCount
+                else:
+                    totalValue = info['deliverie']        
                 
-
                 value = percentage(info[i], totalValue, showPercent=False)
                 
                 rates.append((i, value))
